@@ -77,14 +77,14 @@ void AIStupidEngine::Refresh()
     m_movement.Move(m_current_time);
 
     if (!m_movement.IsProgressing())
-      m_shoot.SetStrategy(AIShootModule::SKIP_TURN);
+	Game::GetInstance()->SetState(Game::END_TURN);
   }
 
 //   switch (m_step)
 //     {
 //     case 0:
 //       if (m_nearest_enemy) {
-//         // we already knows who to shoot
+//         // we already know whom to shoot
 //         m_step = 1;
 //       } else {
 //         m_movement.Move(m_current_time);
