@@ -44,8 +44,6 @@ const uint PAUSE_CHG_DIRECTION=80; // ms
 bool ComputeHeightMovement(Character &character, int &height,
                            bool falling)
 {
-  int y_floor=character.GetY();
-
   if( character.IsInVacuum( Point2i(character.GetDirection(), 0))
   && !character.IsInVacuum( Point2i(character.GetDirection(), +1)) ){
     //Land is flat, we can move!
@@ -57,15 +55,14 @@ bool ComputeHeightMovement(Character &character, int &height,
   if( character.IsInVacuum( Point2i(character.GetDirection(), 0)) ){
     //Try to go down:
     for(height = 2; height <= MAX_FALLING_HEIGHT ; height++){
-      if( !character.IsInVacuum(Point2i(character.GetDirection(), height))
-      ||  character.FootsOnFloor(y_floor+height)){
+      if( !character.IsInVacuum(Point2i(character.GetDirection(), height))) {
         height--;
         return true;
       }
     }
-    //We can go down, but the step is to big -> the character will fall.
+    //We can go down, but the step is too big -> the character will fall
     if (falling) {
-      character.SetX (character.GetX() +character.GetDirection());
+      character.SetX (character.GetXdouble() +character.GetDirection());
       character.UpdatePosition();
       character.SetMovement("fall");
     }
@@ -87,10 +84,10 @@ void MoveCharacter(Character &character, bool slowly)
   int height;
   bool ghost;
   uint walking_pause = GameMode::GetInstance()->character.walking_pause;
-  
+
   if (slowly)
     walking_pause *= 10;
-  else 
+  else
     ActiveCharacter().SetMovement("walk"); // avoid sliding effect when not right or left key is released while releasing shift
 
   // If character moves out of the world, no need to go further: it is dead
