@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,31 +22,38 @@
 #ifndef CHECK_BOX_H
 #define CHECK_BOX_H
 
-#include "../include/base.h"
-#include "../graphic/text.h"
-#include "../gui/widget.h"
-#include "../graphic/sprite.h"
+#include "include/base.h"
+#include "gui/widget.h"
 #include <string>
 
+class Sprite;
+class Text;
+
 class CheckBox : public Widget
 {
+  /* If you need this, implement it (correctly)*/
+ CheckBox(const CheckBox&);
+ CheckBox operator=(const CheckBox&);
+ /**********************************************/
+ void Init(uint width);
+
  protected:
   Text *txt_label;
   bool m_value;
   Sprite *m_checked_image;
-  bool hidden;
-   
+
  public:
-  CheckBox(const std::string &label, const Rectanglei &rect, bool value = true);
+  CheckBox(const std::string &label, uint width, bool value = true);
+  CheckBox(Text* text, uint width, bool value = true);
   ~CheckBox();
-  void Draw(const Point2i &mousePosition, Surface& surf) const;
-  Widget* Clic(const Point2i &mousePosition, uint button) ;
-  void SetSizePosition(const Rectanglei &rect);
 
-  bool GetValue() const;
-  void SetValue(bool value);
+  virtual void Draw(const Point2i &mousePosition) const;
+  virtual Widget* Click(const Point2i&, uint) { return this; };
+  virtual Widget* ClickUp(const Point2i &mousePosition, uint button);
+  virtual void Pack();
 
-  void SetVisible(bool visible);
+  bool GetValue() const { return m_value; };
+  void SetValue(bool value) { m_value = value; };
 };
 
 #endif
