@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,20 +19,23 @@
  * Label in GUI.
  *****************************************************************************/
 
-#include "label.h"
+#include "gui/label.h"
+#include "graphic/text.h"
 
-Label::Label (const std::string &label, const Rectanglei &rect, Font& _font,
-	      const Color& color, bool _center, bool _shadowed) 
-  : font_color(color)
+Label::Label (const std::string &label,
+              uint max_width,
+              Font::font_size_t fsize,
+              Font::font_style_t fstyle,
+              const Color& color,
+              bool _center,
+              bool shadowed):
+  center(_center)
 {
-  position = rect.GetPosition();
-  size = rect.GetSize();
-  font = &_font;
-  center = _center;
-  shadowed = _shadowed;
-  hidden = false;
-  txt_label = new Text(label, font_color, &_font, shadowed);
-  txt_label->SetMaxWidth(GetSizeX());
+  Widget::SetFont(color, fsize, fstyle, shadowed, false);
+
+  size.x = max_width;
+  txt_label = new Text(label, color, fsize, fstyle, shadowed, label.empty());
+  txt_label->SetMaxWidth(size.x);
   size.y = txt_label->GetHeight();
 }
 
@@ -41,30 +44,30 @@ Label::~Label()
   delete txt_label;
 }
 
-void Label::Draw(const Point2i &mousePosition, Surface& surf) const
+void Label::Draw(const Point2i &/*mousePosition*/) const
 {
-  if (!hidden) 
-    {
-      if (!center)
-	txt_label->DrawTopLeft(position);
-      else
-	txt_label->DrawCenterTop(position.x + size.x/2, position.y);
-    }
+  if (!center)
+    txt_label->DrawTopLeft(position);
+  else
+    txt_label->DrawCenterTop(Point2i(position.x + size.x/2, position.y));
 }
 
-void Label::SetSizePosition(const Rectanglei &rect)
+void Label::Pack()
 {
-  StdSetSizePosition(rect);
-  txt_label->SetMaxWidth(GetSizeX());
+  txt_label->SetMaxWidth(size.x);
   size.y = txt_label->GetHeight();
 }
 
 void Label::SetText(const std::string &new_txt)
 {
-  need_redrawing = true;
-  delete txt_label;
-  txt_label = new Text(new_txt, font_color, font, shadowed);
-  txt_label->SetMaxWidth(GetSizeX());
+  NeedRedrawing();
+
+  if (txt_label)
+    delete txt_label;
+
+  txt_label = new Text(new_txt, GetFontColor(), GetFontSize(), GetFontStyle(), IsFontShadowed(), new_txt.empty());
+  txt_label->SetMaxWidth(size.x);
+  size.y = txt_label->GetHeight();
 }
 
 const std::string& Label::GetText() const
@@ -72,10 +75,7 @@ const std::string& Label::GetText() const
   return txt_label->GetText();
 }
 
-void Label::SetVisible(bool visible)
+void Label::OnFontChange()
 {
-  if (hidden == visible) {
-    hidden = !visible;
-    need_redrawing = true;
-  }
+  SetText(GetText());
 }
