@@ -34,6 +34,11 @@ MsgBox::MsgBox(const Point2i& size, Font::font_size_t fsize, Font::font_style_t
 }
 
 MsgBox::~MsgBox()
+{
+  Clear();
+}
+
+void MsgBox::Clear()
 {
   for (std::list<Text*>::iterator t=messages.begin(); t != messages.end(); t++)
     delete *t;
@@ -80,7 +85,7 @@ void MsgBox::NewMessage(const std::string &msg, const Color& color)
 
 void MsgBox::Draw(const Point2i &/*mousePosition*/) const
 {
-  Surface& surf = AppWormux::GetInstance()->video->window;
+  Surface& surf = GetMainWindow();
 
   // Draw the border
   surf.BoxColor(*this, defaultOptionColorBox);
