@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,14 +23,14 @@
 #define BASE_H
 //-----------------------------------------------------------------------------
 
-// Mode debogage ? Peut-tre dsactiv en ajoutant -DRELEASE  la compilation
+// Debug mode can be deactivated by adding -DRELEASE when compiling
 #ifndef DEBUG
 #  define RELEASE
 #endif
 
 //-----------------------------------------------------------------------------
 
-// Types non signes
+#ifndef _MSC_VER
 typedef unsigned char  uchar;
 typedef unsigned short ushort;
 typedef unsigned int   uint;
@@ -39,6 +39,19 @@ typedef unsigned char  uint8;
 //typedef unsigned long uint32;
 typedef signed char    sint8;
 typedef signed long    sint32;
+#else
+typedef unsigned __int8  uchar;
+typedef unsigned __int16 ushort;
+typedef unsigned int     uint;
+typedef unsigned long    ulong;
+typedef unsigned __int8  uint8;
+typedef signed __int8    sint8;
+typedef signed __int32   sint32;
+typedef long int         ssize_t;
+
+typedef signed   __int16  int16_t;
+typedef unsigned __int32  uint32_t;
+#endif
 
 //-----------------------------------------------------------------------------
 
@@ -46,6 +59,6 @@ typedef signed long    sint32;
 #define STR(x) XSTR(x)
 
 //-----------------------------------------------------------------------------
-#include "../tool/error.h"
+#include "tool/error.h"
 //-----------------------------------------------------------------------------
 #endif
