@@ -74,17 +74,17 @@ class IndexServer : public Singleton<IndexServer>
   void NewMsg(IndexServerMsg msg_id);
   void Batch(const int &nbr);
   void Batch(const std::string &str);
-  void SendMsg();
+  bool SendMsg();
   int ReceiveInt();
-  std::string ReceiveStr();
+  std::string ReceiveStr(size_t maxlen);
 
   // Gives the address of a server in the list
   bool GetServerAddress(std::string & address, int & port, uint& nb_tries);
   // Connect to a server
-  bool ConnectTo(const std::string & address, const int & port);
+  connection_state_t ConnectTo(const std::string & address, const int & port);
 
   // Perform a handshake with the server
-  bool HandShake();
+  connection_state_t HandShake();
 public:
   IndexServer();
   ~IndexServer();
