@@ -58,8 +58,12 @@
 #  include <arpa/nameser.h>
 #  include <resolv.h>
 #  include <errno.h>
+#  include <unistd.h>
 #endif
 
+#include "team/team.h"
+#include "team/teams_list.h"
+
 //-----------------------------------------------------------------------------
 
 int  Network::num_objects = 0;
@@ -98,16 +102,7 @@ Network::Network(const std::string& passwd):
   cpu(),
   sync_lock(false)
 {
-  const char *nick = NULL;
-#ifdef WIN32
-  char  buffer[32];
-  DWORD size = 32;
-  if (GetUserName(buffer, &size))
-    nick = buffer;
-#else
-  nick = getenv("USER");
-#endif
-  nickname = (nick) ? nick : _("Unnamed");
+  nickname = GetDefaultNickname();
   sdlnet_initialized = false;
   num_objects++;
 }
@@ -135,6 +130,34 @@ Network::~Network()
 
 //-----------------------------------------------------------------------------
 
+std::string Network::GetDefaultNickname() const
+{
+  std::string s_nick;
+  const char *nick = NULL;
+#ifdef WIN32
+  char  buffer[32];
+  DWORD size = 32;
+  if (GetUserName(buffer, &size))
+    nick = buffer;
+#else
+  nick = getenv("USER");
+#endif
+  s_nick = (nick) ? nick : _("Unnamed");
+  return s_nick;
+}
+
+void Network::SetNickname(const std::string& _nickname)
+{
+  nickname = _nickname;
+}
+
+const std::string& Network::GetNickname() const
+{
+  return nickname;
+}
+
+//-----------------------------------------------------------------------------
+
 bool Network::ThreadToContinue() const
 {
   return !stop_thread;
@@ -154,7 +177,7 @@ void Network::ReceiveActions()
 
   while (ThreadToContinue()) // While the connection is up
   {
-    if (state == NETWORK_PLAYING && cpu.size() == 0)
+    if (state == NETWORK_PLAYING && cpu.empty())
     {
       // If while playing everybody disconnected, just quit
       break;
@@ -165,15 +188,6 @@ void Network::ReceiveActions()
     {
       WaitActionSleep();
 
-      if (cpu.empty()) {
-        if (IsClient()) {
-          fprintf(stderr, "you are alone!\n");
-	  stop_thread = true;
-        }
-        // Even for server, as Visual Studio in debug mode has trouble with that loop
-	continue;
-      }
-
       // Check forced disconnections
       for (dst_cpu = cpu.begin();
            ThreadToContinue() && dst_cpu != cpu.end();
@@ -182,10 +196,21 @@ void Network::ReceiveActions()
         if((*dst_cpu)->force_disconnect)
         {
           dst_cpu = CloseConnection(dst_cpu);
-          continue;
+          if (cpu.empty())
+            break; // Let it be handled afterwards
         }
       }
 
+      // List is now maybe empty
+      if (cpu.empty()) {
+        if (IsClient()) {
+          fprintf(stderr, "you are alone!\n");
+	  stop_thread = true;
+          return; // We really don't need to go through the loops
+        }
+        // Even for server, as Visual Studio in debug mode has trouble with that loop
+	continue;
+      }
       int num_ready = SDLNet_CheckSockets(socket_set, 100);
       // Means something is available
       if (num_ready>0)
@@ -209,8 +234,14 @@ void Network::ReceiveActions()
         if( packet_size == -1) { // An error occured during the reception
           dst_cpu = CloseConnection(dst_cpu);
           // Please Visual Studio that in debug mode has trouble with continuing
-          if (cpu.empty())
+          if (cpu.empty()) {
+            if (IsClient()) {
+              fprintf(stderr, "you are alone!\n");
+	      stop_thread = true;
+              return; // We really don't need to go through the loops
+            }
             break;
+          }
           continue;
         } else
         if (packet_size == 0) // We didn't receive the full packet yet
@@ -226,9 +257,6 @@ void Network::ReceiveActions()
 #endif
 
         Action* a = new Action(packet, (*dst_cpu));
-#ifdef DEBUG
-        MSG_DEBUG("network.crc", "CRC : received %d, computed %d", a->GetCRC(), a->ComputeCRC());
-#endif
         if(!a->CheckCRC()) {
           MSG_DEBUG("network.crc_bad","!!! Bad CRC for action received !!!");
           delete a;
@@ -238,6 +266,15 @@ void Network::ReceiveActions()
           HandleAction(a, *dst_cpu);
         }
         free(packet);
+
+        if (cpu.empty()) {
+          if (IsClient()) {
+            fprintf(stderr, "you are alone!\n");
+            stop_thread = true;
+            return; // We really don't need to go through the loops
+          }
+          break;
+        }
       }
     }
   }
@@ -310,9 +347,16 @@ typedef int SOCKET;
 # define SOCKET_ERROR    (-1)
 # define INVALID_SOCKET  (-1)
 # define closesocket(fd) close(fd)
+
+// For Mac OS X
+#ifndef AI_NUMERICSERV
+#define AI_NUMERICSERV 0
 #endif
 
-connection_state_t Network::GetError() const
+#endif
+
+// static method
+connection_state_t Network::GetError()
 {
 #ifdef WIN32
   int code = WSAGetLastError();
@@ -338,7 +382,9 @@ connection_state_t Network::GetError() const
 #endif
 }
 
-connection_state_t Network::CheckHost(const std::string &host, int prt) const
+#ifdef WIN32
+
+connection_state_t WIN32_CheckHost(const std::string &host, int prt)
 {
   MSG_DEBUG("network", "Checking connection to %s:%i", host.c_str(), prt);
 
@@ -352,13 +398,8 @@ connection_state_t Network::CheckHost(const std::string &host, int prt) const
     return CONN_BAD_SOCKET;
 
   // Set the timeout
-#ifdef WIN32
   int timeout = 5000; //ms
-#else
-  struct timeval timeout;
-  memset(&timeout, 0, sizeof(timeout));
-  timeout.tv_sec = 5; // 5seconds timeout
-#endif
+
   if (setsockopt(fd, SOL_SOCKET, SO_RCVTIMEO, (SOCKET_PARAM*)&timeout, sizeof(timeout)) == SOCKET_ERROR)
   {
     fprintf(stderr, "Setting receive timeout on socket failed\n");
@@ -375,11 +416,7 @@ connection_state_t Network::CheckHost(const std::string &host, int prt) const
   memset(&addr, 0, sizeof(addr));
   addr.sin_family = AF_INET;
   addr.sin_port = htons(prt);
-#ifndef WIN32
-  addr.sin_addr.s_addr = *(in_addr_t*)*hostinfo->h_addr_list;
-#else
   addr.sin_addr.s_addr = inet_addr(inet_ntoa (*(struct in_addr *)*hostinfo->h_addr_list));
-#endif
 
   if( connect(fd, (struct sockaddr*) &addr, sizeof(addr)) == SOCKET_ERROR )
   {
@@ -389,19 +426,153 @@ connection_state_t Network::CheckHost(const std::string &host, int prt) const
   return CONNECTED;
 }
 
+#else
+
+connection_state_t POSIX_CheckHost(const std::string &host, int prt)
+{
+  MSG_DEBUG("network", "Checking connection to %s:%i", host.c_str(), prt);
+
+  connection_state_t s;
+  int r;
+  SOCKET sfd;
+  char port[10];
+  struct addrinfo hints;
+  struct addrinfo *result, *rp;
+
+  memset(&hints, 0, sizeof(struct addrinfo));
+  hints.ai_family = AF_UNSPEC;      /* Allow IPv4 or IPv6 */
+  hints.ai_socktype = SOCK_STREAM;  /* TCP protocol only */
+  hints.ai_flags =  AI_NUMERICSERV; /* Service is a numeric port number */
+  hints.ai_protocol = IPPROTO_TCP;
+
+  snprintf(port, 10, "%d", prt);
+
+  r = getaddrinfo(host.c_str(), port, &hints, &result);
+  if (r != 0) {
+
+    fprintf(stderr, "getaddrinfo returns %d\n", r);
+
+    switch (r) {
+    case EAI_ADDRFAMILY:
+      fprintf(stderr, "The specified network host does not have any network addresses in the requested address family.\n");
+      break;
+    case EAI_AGAIN:
+      fprintf(stderr, "The name server returned a temporary failure indication.  Try again later.\n");
+      break;
+    case EAI_BADFLAGS:
+      fprintf(stderr, "ai_flags contains invalid flags.\n");
+      break;
+    case EAI_FAIL:
+      fprintf(stderr, "The name server returned a permanent failure indication.\n");
+      break;
+    case EAI_FAMILY:
+      fprintf(stderr, "The requested address family is not supported at all.\n");
+      break;
+    case EAI_MEMORY:
+      fprintf(stderr, "Out of memory.\n");
+      break;
+    case EAI_NODATA:
+      fprintf(stderr, "The specified network host exists, but does not have any network addresses defined.\n");
+      break;
+#ifndef WIN32 // AI_NUMERICSERV not defined under Windows
+    case EAI_NONAME:
+      fprintf(stderr, "The node or service is not known; or both node and service are NULL; "
+	      "or AI_NUMERICSERV was specified in hints.ai_flags and  service  was  not  a  numeric port-number string.\n");
+      break;
+#endif
+    case EAI_SERVICE:
+      fprintf(stderr, "The requested service is not available for the requested socket type.  It may be available through another socket type.\n");
+      break;
+    case EAI_SOCKTYPE:
+      fprintf(stderr, "The requested socket type is not supported at all.\n");
+      break;
+    case EAI_SYSTEM:
+      fprintf(stderr, "Other system error, check errno for details.\n");
+      break;
+    }
+
+    if (r == EAI_NONAME) {
+      s = CONN_BAD_HOST;
+      goto error;
+    }
+
+    s = CONN_BAD_SOCKET;
+    goto error;
+  }
+
+  /* getaddrinfo() returns a list of address structures.
+     Try each address until we successfully connect(2).
+     If socket(2) (or connect(2)) fails, we (close the socket
+     and) try the next address. */
+  for (rp = result; rp != NULL; rp = rp->ai_next) {
+
+    sfd = socket(rp->ai_family, rp->ai_socktype, rp->ai_protocol);
+
+    if (sfd == -1)
+      continue;
+
+    // Try to set the timeout
+    struct timeval timeout;
+    memset(&timeout, 0, sizeof(timeout));
+    timeout.tv_sec = 5; // 5seconds timeout
+
+    if (setsockopt(sfd, SOL_SOCKET, SO_RCVTIMEO, (SOCKET_PARAM*)&timeout, sizeof(timeout)) == SOCKET_ERROR) {
+      fprintf(stderr, "Setting receive timeout on socket failed\n");
+      closesocket(sfd);
+      continue;
+    }
+
+    if (setsockopt(sfd, SOL_SOCKET, SO_SNDTIMEO, (SOCKET_PARAM*)&timeout, sizeof(timeout)) == SOCKET_ERROR) {
+      fprintf(stderr, "Setting send timeout on socket failed\n");
+      closesocket(sfd);
+      continue;
+    }
+
+    if (connect(sfd, rp->ai_addr, rp->ai_addrlen) != -1)
+      break; /* Success */
+
+    closesocket(sfd);
+  }
+
+  if (rp == NULL) { /* No address succeeded */
+    fprintf(stderr, "Could not connect\n");
+    s = CONN_BAD_SOCKET;
+    goto error;
+  }
+
+  closesocket(sfd);
+
+  MSG_DEBUG("network", "CheckHost %s:%d : OK", host.c_str(), prt);
+  s = CONNECTED;
+
+ error:
+  freeaddrinfo(result); /* No longer needed */
+  return s;
+}
+#endif
+
+connection_state_t Network::CheckHost(const std::string &host, int prt)
+{
+#ifdef WIN32
+  return WIN32_CheckHost(host, prt);
+#else
+  return POSIX_CheckHost(host, prt);
+#endif
+}
+
 //-----------------------------------------------------------------------------
 //----------------       Action handling methods   ----------------------------
 //-----------------------------------------------------------------------------
 
 // Send Messages
-void Network::SendAction(const Action* a) const
+void Network::SendAction(const Action& a) const
 {
   MSG_DEBUG("network.traffic","Send action %s",
-            ActionHandler::GetInstance()->GetActionName(a->GetType()).c_str());
+            ActionHandler::GetInstance()->GetActionName(a.GetType()).c_str());
 
   int size;
   char* packet;
-  a->WritePacket(packet, size);
+  a.WriteToPacket(packet, size);
 
   ASSERT(packet != NULL);
   SendPacket(packet, size);
@@ -519,7 +690,7 @@ void Network::SendNetworkState() const
 {
   Action a(Action::ACTION_NETWORK_CHANGE_STATE);
   a.Push(state);
-  SendAction(&a);
+  SendAction(a);
 }
 
 void Network::SetTurnMaster(bool master)
@@ -539,20 +710,31 @@ bool Network::IsTurnMaster() const
 // Static methods usefull to communicate without action
 // (index server, handshake, ...)
 
-void Network::Send(TCPsocket& socket, const int& nbr)
+bool Network::Send(TCPsocket& socket, const int& nbr)
 {
   char packet[4];
   // this is not cute, but we don't want an int -> uint conversion here
   Uint32 u_nbr = *((const Uint32*)&nbr);
 
   SDLNet_Write32(u_nbr, packet);
-  SDLNet_TCP_Send(socket, packet, sizeof(packet));
+  int len = SDLNet_TCP_Send(socket, packet, sizeof(packet));
+  if (len < int(sizeof(packet)))
+    return false;
+
+  return true;
 }
 
-void Network::Send(TCPsocket& socket, const std::string &str)
+bool Network::Send(TCPsocket& socket, const std::string &str)
 {
-  Send(socket, str.size());
-  SDLNet_TCP_Send(socket, (void*)str.c_str(), str.size());
+  bool r = Send(socket, str.size());
+  if (!r)
+    return false;
+
+  int len = SDLNet_TCP_Send(socket, (void*)str.c_str(), str.size());
+  if (len < int(str.size()))
+    return false;
+
+  return true;
 }
 
 uint Network::Batch(void* buffer, const int& nbr)
@@ -575,10 +757,16 @@ uint Network::Batch(void* buffer, const std::string &str)
 
 // A batch consists in a msg id, a size, and the batch itself.
 // Size wasn't known yet, so write it now.
-void Network::SendBatch(TCPsocket& socket, void* data, size_t len)
+bool Network::SendBatch(TCPsocket& socket, void* data, size_t len)
 {
   SDLNet_Write32(len, (void*)( ((char*)data)+4 ) );
-  SDLNet_TCP_Send(socket, data, len);
+
+  int size = SDLNet_TCP_Send(socket, data, len);
+  if (size < int(len)) {
+    MSG_DEBUG("network", "size = %d", size);
+    return false;
+  }
+  return true;
 }
 
 int Network::ReceiveInt(SDLNet_SocketSet& sock_set, TCPsocket& socket, int& nbr)
@@ -611,7 +799,7 @@ int Network::ReceiveInt(SDLNet_SocketSet& sock_set, TCPsocket& socket, int& nbr)
   return r;
 }
 
-int Network::ReceiveStr(SDLNet_SocketSet& sock_set, TCPsocket& socket, std::string &_str)
+int Network::ReceiveStr(SDLNet_SocketSet& sock_set, TCPsocket& socket, std::string &_str, size_t maxlen)
 {
   int r;
   uint size = 0;
@@ -627,6 +815,11 @@ int Network::ReceiveStr(SDLNet_SocketSet& sock_set, TCPsocket& socket, std::stri
     goto out;
   }
 
+  if (size > maxlen) {
+    r = -1;
+    goto out;
+  }
+
   if (SDLNet_CheckSockets(sock_set, 5000) == 0) {
     r = -1;
     goto out;
