@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 #ifndef BULLET_H
 #define BULLET_H
-#include "particle.h"
+#include "particles/particle.h"
 
 class BulletParticle : public Particle
 {
@@ -33,4 +33,4 @@ class BulletParticle : public Particle
     void SignalRebound();
 };
 
-#endif
+#endif /* BULLET_H */
