@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,8 +19,9 @@
  * Particle Engine
  *****************************************************************************/
 
-#include "smoke.h"
-#include "particle.h"
+#include "particles/smoke.h"
+#include "particles/particle.h"
+#include "graphic/sprite.h"
 
 Smoke::Smoke() :
   Particle("smoke_particle")
