@@ -29,6 +29,16 @@ bool DoesFileExist(const std::string &name);
 // Check if the folder exists
 bool IsFolderExist(const std::string &name);
 
+// Create the folder if it does not exist yet
+bool CreateFolder(const std::string &name);
+
+// Delete the folder if it exists
+bool DeleteFolder(const std::string &name);
+
+
+// Delete the file if it exists
+bool DeleteFile(const std::string &name);
+
 // Find the extension part of a filename
 std::string FileExtension(const std::string &name);
 
@@ -44,4 +54,6 @@ FolderSearch *OpenFolder(const std::string& dirname);
 const char* FolderSearchNext(FolderSearch *f);
 void CloseFolder(FolderSearch *f);
 
+std::string FormatFileName(const std::string &name);
+
 #endif
