@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,23 +21,15 @@
 
 #ifndef BAZOOKA_H
 #define BAZOOKA_H
-#include "launcher.h"
 
-class BazookaRocket : public WeaponProjectile
-{
-  ParticleEngine smoke_engine;
-public:
-  BazookaRocket(ExplosiveWeaponConfig& cfg, WeaponLauncher * p_launcher);
-  void Refresh();
-protected:
-  void SignalOutOfMap();
-  void SignalDrowning();
-};
+#include "weapon/weapon_launcher.h"
 
 class Bazooka : public WeaponLauncher
 {
  public:
   Bazooka();
+  std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
+  void UpdateTranslationStrings();
  protected:
   WeaponProjectile * GetProjectileInstance();
 };
