@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,17 +30,27 @@ class JetPack : public Weapon
     double m_x_force;
     double m_y_force;
 
-    int channel;
+    SoundSample flying_sound;
 
-  // Jetpack fuel.
+    // Jetpack fuel.
     uint m_last_fuel_down;
 
   public:
     JetPack();
     void Reset();
-    void HandleKeyEvent(Action::Action_t action, Keyboard::Key_Event_t event_type) ;
-    void SignalTurnEnd();
-    void ActionStopUse();
+    virtual void SignalTurnEnd() { p_Deselect(); };
+    virtual void ActionStopUse();
+
+    virtual void HandleKeyPressed_Up(bool shift);
+    virtual void HandleKeyReleased_Up(bool shift);
+    virtual void HandleKeyPressed_MoveLeft(bool shift);
+    virtual void HandleKeyReleased_MoveLeft(bool shift);
+    virtual void HandleKeyPressed_MoveRight(bool shift);
+    virtual void HandleKeyReleased_MoveRight(bool shift);
+    virtual void HandleKeyPressed_Shoot(bool shift);
+
+    void UpdateTranslationStrings();
+    std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
 
   protected:
     void Refresh();
@@ -48,12 +58,13 @@ class JetPack : public Weapon
     void p_Deselect();
     bool p_Shoot();
 
+  private:
     void GoUp();
     void GoLeft();
     void GoRight();
-    void StopUp();
-    void StopLeft();
-    void StopRight();
+    void StopUp() { m_y_force = 0.0; StopUse(); };
+    void StopLeft() { m_x_force = 0.0; StopUse(); };
+    void StopRight() { m_x_force = 0.0; StopUse(); };
     void StartUse();
     void StopUse();
 };
